==> galil_gclib_1_31_7.zip: doc/html/annotated_dup.js <==
var annotated_dup =
[
    [ "examples", "namespaceexamples.html", [
      [ "Examples", "classexamples_1_1_examples.html", "classexamples_1_1_examples" ],
      [ "Commands_Example", "classexamples_1_1_commands___example.html", "classexamples_1_1_commands___example" ],
      [ "Contour_Example", "classexamples_1_1_contour___example.html", "classexamples_1_1_contour___example" ],
      [ "IP_Assigner_Example", "classexamples_1_1_i_p___assigner___example.html", "classexamples_1_1_i_p___assigner___example" ],
      [ "Jog_Example", "classexamples_1_1_jog___example.html", "classexamples_1_1_jog___example" ],
      [ "Message_Example", "classexamples_1_1_message___example.html", "classexamples_1_1_message___example" ],
      [ "Motion_Complete_Example", "classexamples_1_1_motion___complete___example.html", "classexamples_1_1_motion___complete___example" ],
      [ "Position_Tracking_Example", "classexamples_1_1_position___tracking___example.html", "classexamples_1_1_position___tracking___example" ],
      [ "Record_Position_Example", "classexamples_1_1_record___position___example.html", "classexamples_1_1_record___position___example" ],
      [ "Remote_Client_Example", "classexamples_1_1_remote___client___example.html", "classexamples_1_1_remote___client___example" ],
      [ "Remote_Server_Example", "classexamples_1_1_remote___server___example.html", "classexamples_1_1_remote___server___example" ],
      [ "Vector_Mode_Example", "classexamples_1_1_vector___mode___example.html", "classexamples_1_1_vector___mode___example" ]
    ] ],
    [ "GDataRecord", "union_g_data_record.html", "union_g_data_record" ],
    [ "GDataRecord1802", "struct_g_data_record1802.html", "struct_g_data_record1802" ],
    [ "GDataRecord1806", "struct_g_data_record1806.html", "struct_g_data_record1806" ],
    [ "GDataRecord2103", "struct_g_data_record2103.html", "struct_g_data_record2103" ],
    [ "GDataRecord30000", "struct_g_data_record30000.html", "struct_g_data_record30000" ],
    [ "GDataRecord4000", "struct_g_data_record4000.html", "struct_g_data_record4000" ],
    [ "GDataRecord47000_ENC", "struct_g_data_record47000___e_n_c.html", "struct_g_data_record47000___e_n_c" ],
    [ "GDataRecord47162", "struct_g_data_record47162.html", "struct_g_data_record47162" ],
    [ "GDataRecord47300_24EX", "struct_g_data_record47300__24_e_x.html", "struct_g_data_record47300__24_e_x" ],
    [ "GDataRecord47300_ENC", "struct_g_data_record47300___e_n_c.html", "struct_g_data_record47300___e_n_c" ],
    [ "GDataRecord52000", "struct_g_data_record52000.html", "struct_g_data_record52000" ],
    [ "H_ArrayData", "struct_h___array_data.html", "struct_h___array_data" ]
];

==> galil_gclib_2_0_7.zip: doc/html/annotated_dup.js <==
var annotated_dup =
[
    [ "examples", "namespaceexamples.html", [
      [ "Examples", "classexamples_1_1_examples.html", "classexamples_1_1_examples" ],
      [ "Commands_Example", "classexamples_1_1_commands___example.html", "classexamples_1_1_commands___example" ],
      [ "Contour_Example", "classexamples_1_1_contour___example.html", "classexamples_1_1_contour___example" ],
      [ "IP_Assigner_Example", "classexamples_1_1_i_p___assigner___example.html", "classexamples_1_1_i_p___assigner___example" ],
      [ "Jog_Example", "classexamples_1_1_jog___example.html", "classexamples_1_1_jog___example" ],
      [ "Message_Example", "classexamples_1_1_message___example.html", "classexamples_1_1_message___example" ],
      [ "Motion_Complete_Example", "classexamples_1_1_motion___complete___example.html", "classexamples_1_1_motion___complete___example" ],
      [ "Position_Tracking_Example", "classexamples_1_1_position___tracking___example.html", "classexamples_1_1_position___tracking___example" ],
      [ "Record_Position_Example", "classexamples_1_1_record___position___example.html", "classexamples_1_1_record___position___example" ],
      [ "Remote_Client_Example", "classexamples_1_1_remote___client___example.html", "classexamples_1_1_remote___client___example" ],
      [ "Remote_Server_Example", "classexamples_1_1_remote___server___example.html", "classexamples_1_1_remote___server___example" ],
      [ "Vector_Mode_Example", "classexamples_1_1_vector___mode___example.html", "classexamples_1_1_vector___mode___example" ]
    ] ],
    [ "gclib_example", "namespacegclib__example.html", [
      [ "MainForm", "classgclib__example_1_1_main_form.html", "classgclib__example_1_1_main_form" ],
      [ "Program", "classgclib__example_1_1_program.html", null ]
    ] ],
    [ "gclibjava", "namespacegclibjava.html", [
      [ "GclibJava", "classgclibjava_1_1_gclib_java.html", "classgclibjava_1_1_gclib_java" ],
      [ "GclibJavaException", "classgclibjava_1_1_gclib_java_exception.html", "classgclibjava_1_1_gclib_java_exception" ]
    ] ],
    [ "gclibtest", null, [
      [ "GclibTest", "classgclibtest_1_1_gclib_test.html", "classgclibtest_1_1_gclib_test" ]
    ] ],
    [ "vb", "namespacevb.html", [
      [ "Gclib", "classvb_1_1_gclib.html", "classvb_1_1_gclib" ]
    ] ],
    [ "Galil", "class_galil.html", "class_galil" ],
    [ "GalilPrivate", "class_galil_private.html", "class_galil_private" ],
    [ "gclib", "classgclib.html", "classgclib" ],
    [ "GDataRecord", "union_g_data_record.html", "union_g_data_record" ],
    [ "GDataRecord1802", "struct_g_data_record1802.html", "struct_g_data_record1802" ],
    [ "GDataRecord1806", "struct_g_data_record1806.html", "struct_g_data_record1806" ],
    [ "GDataRecord2103", "struct_g_data_record2103.html", "struct_g_data_record2103" ],
    [ "GDataRecord30000", "struct_g_data_record30000.html", "struct_g_data_record30000" ],
    [ "GDataRecord4000", "struct_g_data_record4000.html", "struct_g_data_record4000" ],
    [ "GDataRecord47000_ENC", "struct_g_data_record47000___e_n_c.html", "struct_g_data_record47000___e_n_c" ],
    [ "GDataRecord47162", "struct_g_data_record47162.html", "struct_g_data_record47162" ],
    [ "GDataRecord47300_24EX", "struct_g_data_record47300__24_e_x.html", "struct_g_data_record47300__24_e_x" ],
    [ "GDataRecord47300_ENC", "struct_g_data_record47300___e_n_c.html", "struct_g_data_record47300___e_n_c" ],
    [ "GDataRecord52000", "struct_g_data_record52000.html", "struct_g_data_record52000" ],
    [ "H_ArrayData", "struct_h___array_data.html", "struct_h___array_data" ],
    [ "Source", "struct_source.html", "struct_source" ]
];
